<?xml version="1.0" encoding="UTF-8" ?>
<!-- $Id: cedram-to-dmlcz-metadata.xsl 712 2008-09-28 11:19:30Z michalr $ -->
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" 
               xmlns:str="http://exslt.org/strings">
    
    <!-- Output setup. -->
    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
    
    <!-- Math expressions conversion. -->
    <xsl:template match="texmath">
        <xsl:if test="@type='inline'">$<xsl:value-of select="."/>$</xsl:if>
        <xsl:if test="@type='display'">\[<xsl:value-of select="."/>\]</xsl:if>
    </xsl:template>
    
    <!-- xml:lang attribute conversion. -->
    <xsl:template match="@xml:lang">
        <xsl:choose>
            <xsl:when test=".='cs'">
                <xsl:attribute name="lang">cze</xsl:attribute>
            </xsl:when>
            <xsl:when test=".='en'">
                <xsl:attribute name="lang">eng</xsl:attribute>
            </xsl:when>
            <xsl:when test=".='de'">
                <xsl:attribute name="lang">ger</xsl:attribute>
            </xsl:when>
            <xsl:when test=".='fr'">
                <xsl:attribute name="lang">fre</xsl:attribute>
            </xsl:when>
            <xsl:when test=".='ru'">
                <xsl:attribute name="lang">rus</xsl:attribute>
            </xsl:when>
            <xsl:when test=".='sk'">
                <xsl:attribute name="lang">slo</xsl:attribute>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    
    <!-- Article entry extraction. -->
    <xsl:template match="/">
        <article>
            <xsl:apply-templates select="/article-metadata/article/TeXtitre"/>
            <xsl:apply-templates select="/article-metadata/article/auteur"/>
            <xsl:apply-templates select="/article-metadata/article/langue"/>
            <xsl:apply-templates select="/article-metadata/article/pagedeb"/>
            <xsl:apply-templates select="/article-metadata/article/TeXkeyword"/>
            <xsl:apply-templates select="/article-metadata/article/TeXresume"/>
            <xsl:apply-templates select="/article-metadata/article/msc/msc_primary"/>
            <xsl:apply-templates select="/article-metadata/article/msc/msc_secondary"/>
            <xsl:apply-templates select="/article-metadata/special/TeXtitre"/>
            <xsl:apply-templates select="/article-metadata/special/langue"/>
            <xsl:apply-templates select="/article-metadata/special/pagedeb"/>
            <category>
                <xsl:choose>
                    <xsl:when test="/article-metadata/special[@type]">
                        <xsl:value-of select="/article-metadata/special/@type"/>
                    </xsl:when>
                    <xsl:otherwise>math</xsl:otherwise>
                </xsl:choose>
            </category>
        </article>
    </xsl:template>
    
    <!-- Article titles extraction. -->
    <xsl:template match="TeXtitre">
        <title>
            <xsl:apply-templates select="@xml:lang|*|text()"/>
        </title>
    </xsl:template>
    
    <!-- Article authors extraction. -->
    <xsl:template match="auteur">
        <author>
            <xsl:apply-templates select="./nom"/>
            <xsl:text>, </xsl:text>
            <xsl:apply-templates select="./prenom"/>
        </author>
    </xsl:template>
    
    <!-- Article language extraction. -->
    <xsl:template match="langue">
        <language>
            <xsl:choose>
                <xsl:when test=".='cs'">cze</xsl:when>
                <xsl:when test=".='en'">eng</xsl:when>
                <xsl:when test=".='de'">ger</xsl:when>
                <xsl:when test=".='fr'">fre</xsl:when>
                <xsl:when test=".='ru'">rus</xsl:when>
                <xsl:when test=".='sk'">slo</xsl:when>
            </xsl:choose>
        </language>
    </xsl:template>
    
    <!-- Article pages extraction. -->
    <xsl:template match="pagedeb">
        <range_pages>
            <xsl:value-of select="."/>
            <xsl:text>-</xsl:text>
            <xsl:value-of select="../pagefin"/>
        </range_pages>
    </xsl:template>
    
    <!-- Article keywords extraction. -->
    <xsl:template match="TeXkeyword">
        <keyword>
            <xsl:apply-templates select="@xml:lang|*|text()"/>
        </keyword>
    </xsl:template>
    
    <!-- Article summary and summary language extraction. -->
    <xsl:template match="TeXresume">
        <summary>
            <xsl:apply-templates select="@xml:lang|*|text()"/>
        </summary>
        <lang_summary>
            <xsl:choose>
                <xsl:when test="@xml:lang='cs'">cze</xsl:when>
                <xsl:when test="@xml:lang='en'">eng</xsl:when>
                <xsl:when test="@xml:lang='de'">ger</xsl:when>
                <xsl:when test="@xml:lang='fr'">fre</xsl:when>
                <xsl:when test="@xml:lang='ru'">rus</xsl:when>
                <xsl:when test="@xml:lang='sk'">slo</xsl:when>
            </xsl:choose>
        </lang_summary>
    </xsl:template>
    
    <!-- Primary MSC extraction. -->
    <xsl:template match="msc_primary">
        <msc>
            <xsl:attribute name="revision">
                <xsl:value-of select="../../msc_edition"/>
            </xsl:attribute>
            <xsl:attribute name="type">
                <xsl:text>primary</xsl:text>
            </xsl:attribute>
            <xsl:value-of select='.'/>
        </msc>
    </xsl:template>
    
    <!-- Secondary MSC extraction. -->
    <xsl:template match="msc_secondary">
        <msc>
            <xsl:attribute name="revision">
                <xsl:value-of select="../../msc_edition"/>
            </xsl:attribute>
            <xsl:attribute name="type">
                <xsl:text>secondary</xsl:text>
            </xsl:attribute>
            <xsl:value-of select='.'/>
        </msc>
    </xsl:template>
    
</xsl:transform>
